==> pitivi_0.99.orig.tar.xz: pitivi-0.99/docs/Current_events.md <==
# Releases

For short-term release plans and events, see the calendar
([iCal](https://www.google.com/calendar/ical/m4r5pf5da7c8kdba1cjq2d3jb4%40group.calendar.google.com/public/basic.ics)
or
[HTML](https://www.google.com/calendar/embed?src=m4r5pf5da7c8kdba1cjq2d3jb4%40group.calendar.google.com)).
For long term plans, see the [Roadmap](Roadmap.md).

-   [0.99](releases/0.99.md) “Giant enemy crab” should be released early
    in 2017.

Among the current releases, only the latest release is supported at any
given time (unless otherwise noted):

-   2016 Dec 5th: [0.98](releases/0.98.md) “Getting there”
-   2016 Aug 8th: [0.97](releases/0.97.md)
-   2016 Jun 30th: [0.96](releases/0.96.md) “Cogito Ergo Proxy”
-   2015 Nov 13th: [0.95](releases/0.95.md) “Enfant suisse”
-   2014 Nov 2nd: [0.94](releases/0.94.md) “Tricks or Tracebacks?”
-   2014 Mar 20th: [0.93](releases/0.93.md) “Ra is a Happy”
-   2013 Nov 4th: [0.92](releases/0.92.md) “Baby Steps”
-   2013 Sep 29th: [0.91](releases/0.91.md) “Charming Defects”
-   2012 May 3rd: [0.15.2](releases/0.15.2.md) “I accidentally... the
    whole render”
-   2012 Feb 24th: [0.15.1](releases/0.15.1.md) “Endless Excursion”
-   2011 Sep 27th: [0.15](releases/0.15.md) “Ich bin ein berliner”
-   2011 May 31st: [0.14](releases/0.14.md) “No longer kills kittens”
-   2010 Sep 15th: [0.13.5](releases/0.13.5.md) “I Missed My Lunch”
-   2010 Mar 10th: [0.13.4](releases/0.13.4.md) “Cabernet d’Anjou”
-   2009 Sep 12th: [0.13.3](releases/0.13.3.md) “... we shall never
    (sur)render”
-   2009 Aug 13th: [0.13.2](releases/0.13.2.md) “Jailbreak (out of
    Deadlock City)”
-   2009 May 27th: [0.13.1](releases/0.13.1.md) “L'Aquila Immota Manet :
    The eagle remains unmoved”
-   2008 Dec 11th: [0.11.3](releases/0.11.3.md) “Paella Cubana”
-   2008 Oct 15th: [0.11.2](releases/0.11.2.md) “Milanesa de Lomo”
-   2007 Nov 18th: [0.11.1](releases/0.11.1.md) “A gentlemen game played
    by hooligans”
-   2007 Oct 14th: [0.11.0](releases/0.11.0.md) “A hooligan's game played
    by gentlemen”
-   2007 May 30th: [0.10.3](releases/0.10.3.md) “Got some new t-shirts”
-   2007 Jan 28th: [0.10.2](releases/0.10.2.md) “A New Toy”
-   2006 May 23rd: [0.10.1](releases/0.10.1.md) “Sister and Friend”
-   2006 Apr 26th: 0.10.0 “It's a birthday party”

# Talks

See the Pitivi website's [showcase
page](http://www.pitivi.org/?go=showcase) for video recordings and
slides of some of these talks.

-   2014 July 27th: GUADEC (Pitivi)
-   2013 October 22nd: GStreamer Conference (GES)
-   2013 August 4th: GUADEC (Pitivi)
-   2012 August 27th/28th: GStreamer Conference (GES)
-   2012 July 29th: GUADEC (Pitivi & GES)
-   2012 June 9th: GNOME Asia (Pitivi & GES)
-   2011 Dec 10th: ExpoLibre Talca (Pitivi & GES)
-   2011 May 25th: Meego Conference (GES)
-   2011 May 11th: Libre Graphics Meeting 2011 (Pitivi)
-   2010 March 26th or 28th: Ubuntu Global Jam in Montréal (lightning
    talk about Pitivi, in French)
-   2009 July: GUADEC 2009 (Pitivi)
-   2009 May 8th: Libre Graphics Meeting 2009 (Pitivi)
-   2006 July 22nd: LUGRadio Live 2006
-   2006 June 23rd-30th: GUADEC 2006 (Pitivi)

# In the Media

For a roundup of mentions in the media, see the
[Praise](Praise.md) page.

==> pitivi-2020.09.tar.xz: pitivi-2020.09/docs/Current_events.md <==
# Releases

For short-term release plans and events, see the calendar
([iCal](https://www.google.com/calendar/ical/m4r5pf5da7c8kdba1cjq2d3jb4%40group.calendar.google.com/public/basic.ics)
or
[HTML](https://www.google.com/calendar/embed?src=m4r5pf5da7c8kdba1cjq2d3jb4%40group.calendar.google.com)).
For long term plans, see the [Roadmap](Roadmap.md).

-   2018 Aug 29th: [0.999](releases/0.999.md) “Test me please”

Among the current releases, only the latest release is supported at any
given time (unless otherwise noted):

-   2017 Sep 21st: [0.99](releases/0.99.md) “Ocean Big Chair”
-   2016 Dec 5th: [0.98](releases/0.98.md) “Getting there”
-   2016 Aug 8th: [0.97](releases/0.97.md)
-   2016 Jun 30th: [0.96](releases/0.96.md) “Cogito Ergo Proxy”
-   2015 Nov 13th: [0.95](releases/0.95.md) “Enfant suisse”
-   2014 Nov 2nd: [0.94](releases/0.94.md) “Tricks or Tracebacks?”
-   2014 Mar 20th: [0.93](releases/0.93.md) “Ra is a Happy”
-   2013 Nov 4th: [0.92](releases/0.92.md) “Baby Steps”
-   2013 Sep 29th: [0.91](releases/0.91.md) “Charming Defects”
-   2012 May 3rd: [0.15.2](releases/0.15.2.md) “I accidentally... the
    whole render”
-   2012 Feb 24th: [0.15.1](releases/0.15.1.md) “Endless Excursion”
-   2011 Sep 27th: [0.15](releases/0.15.md) “Ich bin ein berliner”
-   2011 May 31st: [0.14](releases/0.14.md) “No longer kills kittens”
-   2010 Sep 15th: [0.13.5](releases/0.13.5.md) “I Missed My Lunch”
-   2010 Mar 10th: [0.13.4](releases/0.13.4.md) “Cabernet d’Anjou”
-   2009 Sep 12th: [0.13.3](releases/0.13.3.md) “... we shall never
    (sur)render”
-   2009 Aug 13th: [0.13.2](releases/0.13.2.md) “Jailbreak (out of
    Deadlock City)”
-   2009 May 27th: [0.13.1](releases/0.13.1.md) “L'Aquila Immota Manet :
    The eagle remains unmoved”
-   2008 Dec 11th: [0.11.3](releases/0.11.3.md) “Paella Cubana”
-   2008 Oct 15th: [0.11.2](releases/0.11.2.md) “Milanesa de Lomo”
-   2007 Nov 18th: [0.11.1](releases/0.11.1.md) “A gentlemen game played
    by hooligans”
-   2007 Oct 14th: [0.11.0](releases/0.11.0.md) “A hooligan's game played
    by gentlemen”
-   2007 May 30th: [0.10.3](releases/0.10.3.md) “Got some new t-shirts”
-   2007 Jan 28th: [0.10.2](releases/0.10.2.md) “A New Toy”
-   2006 May 23rd: [0.10.1](releases/0.10.1.md) “Sister and Friend”
-   2006 Apr 26th: 0.10.0 “It's a birthday party”

# Talks

See the Pitivi website's [showcase
page](http://www.pitivi.org/?go=showcase) for video recordings and
slides of some of these talks.

-   2014 July 27th: GUADEC (Pitivi)
-   2013 October 22nd: GStreamer Conference (GES)
-   2013 August 4th: GUADEC (Pitivi)
-   2012 August 27th/28th: GStreamer Conference (GES)
-   2012 July 29th: GUADEC (Pitivi & GES)
-   2012 June 9th: GNOME Asia (Pitivi & GES)
-   2011 Dec 10th: ExpoLibre Talca (Pitivi & GES)
-   2011 May 25th: Meego Conference (GES)
-   2011 May 11th: Libre Graphics Meeting 2011 (Pitivi)
-   2010 March 26th or 28th: Ubuntu Global Jam in Montréal (lightning
    talk about Pitivi, in French)
-   2009 July: GUADEC 2009 (Pitivi)
-   2009 May 8th: Libre Graphics Meeting 2009 (Pitivi)
-   2006 July 22nd: LUGRadio Live 2006
-   2006 June 23rd-30th: GUADEC 2006 (Pitivi)

# In the Media

For a roundup of mentions in the media, see the
[Praise](Praise.md) page.
